#
# spec file for package ghc-path-io
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name path-io
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.7.0
Release:        bp155.2.14
Summary:        Interface to ‘directory’ package for users of ‘path’
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-dlist-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-path-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-compat-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
Interface to ‘directory’ package for users of ‘path’.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE.md

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Sun Feb 13 2022 Peter Simons <psimons@suse.com>
- Update path-io to version 1.7.0.
  [#]# Path IO 1.7.0
  * Added `doesPathExist`, `getFileSize`, `renamePath`, and
    `removePathForcibly`.
* Sun Aug  8 2021 psimons@suse.com
- Update path-io to version 1.6.3 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jun 21 2021 psimons@suse.com
- Update path-io to version 1.6.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Jun  5 2021 psimons@suse.com
- Update path-io to version 1.6.3.
  [#]# Path IO 1.6.3
  * Fixed a bug that caused `removeDirLink` fail on Linux because of a
    trailing slash that used to be passed to the underlying
    `removeDirectoryLink` function from the `directory` package. [Issue
    59](https://github.com/mrkkrp/path-io/issues/59).
  * Works with GHC 9.0.1.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Oct 23 2020 psimons@suse.com
- Update path-io to version 1.6.2.
  [#]# Path IO 1.6.2
  * Fixed a bug in the `findFilesWith` and based on it `findFiles` functions.
* Sun Oct 18 2020 psimons@suse.com
- Update path-io to version 1.6.1.
  [#]# Path IO 1.6.1
  * Fixed a space leak in `walkDirAccum`. [Issue
    55](https://github.com/mrkkrp/path-io/issues/55).
* Mon Aug 31 2020 psimons@suse.com
- Update path-io to version 1.6.0 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 25 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Jan  1 2020 psimons@suse.com
- Revise cabal build file to specify more accurate dependencies.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sun Oct 13 2019 psimons@suse.com
- Update path-io to version 1.6.0.
  [#]# Path IO 1.6.0
  * Changed how `copyDirRecur` and `copyDirRecur'` functions work. Previously,
    the functions created empty directories in the destination directory when
    the source directory contained directory symlinks. The symlinked
    directories were not recursively traversed. It also copied symlinked files
    creating normal regular files in the target directory as the result. This
    is fixed so that the function now behaves much like the `cp` utility, not
    traversing symlinked directories, but recreating symlinks in the target
    directory according to their targets in the source directory.
  * Fixed a bug in `createDirLink` which would always fail complaining that
    its destination location does not exist.
  * Dropped support for GHC 8.2.
* Thu Sep 19 2019 psimons@suse.com
- Update path-io to version 1.5.0.
  [#]# Path IO 1.5.0
  * Dropped support for GHC 8.0 and older.
  * Added new functions: `getXdgDirList`, `createFileLink`, `createDirLink`,
    `removeDirLink`, `getSymlinkTarget`.
* Thu Feb 14 2019 psimons@suse.com
- Update path-io to version 1.4.2.
  [#]# Path IO 1.4.2
  * Fixed various bugs in `listDirRecurRel`, `walkDirRel`, and
    `walkDirAccumRel` and clarified their behavior in the docs.
* Sat Jan 19 2019 Peter Simons <psimons@suse.com>
- Update Cabal build instructions for more accurate dependencies.
* Fri Dec 21 2018 psimons@suse.com
- Update path-io to version 1.4.1.
  [#]# Path IO 1.4.1
  * Fixed a bug in `walkDirRel` that resulted in `NotAProperPrefix` exception
    every time the function was called.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Sun Jul 29 2018 psimons@suse.com
- Update path-io to version 1.4.0.
  [#]# Path IO 1.4.0
  * Added relative versions of some actions: `listDirRel`, `listDirRecurRel`,
    `walkDirRel`, and `walkDirAccumRel`.
  * Dropped support for GHC 7.8.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update path-io to version 1.3.3 revision 3.
  * (Hopefully) fixed test suite failure with Cabal 2.0 and GHC 8.2.1.
  * Reduce a number of `(MonadIO m, MonadThrow m)` constraints to just
    `MonadIO m` [#27](https://github.com/mrkkrp/path-io/issues/27)
  * Made `listDirRecur` faster for deep directory trees.
  * Change the default behavior of recursive traversal APIs to not follow
    symbolic links. The change affects the following functions:
    `listDirRecur`, `copyDirRecur`, and `copyDirRecur'`.
  * Add `isSymlink` which allows to test whether a path is a symbolic link.
  * Move the type functions `AbsPath` and `RelPath` to the `AnyPath` type
    class (previously they were standalone closed type families, now they are
    associated types of `AnyPath`).
  * Improved the documentation and metadata.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Fri May  5 2017 psimons@suse.com
- Update to version 1.2.2 revision 1 with cabal2obs.
* Sun Jan  8 2017 psimons@suse.com
- Update to version 1.2.2 with cabal2obs.
* Wed Jan  4 2017 psimons@suse.com
- Update to version 1.2.0 revision 1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 1.2.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.1.0 revision 0 with cabal2obs.
* Tue Mar  8 2016 mimi.vx@gmail.com
- package ghc-path-io updated by st2obs
* Sat Feb 13 2016 mimi.vx@gmail.com
- ghc-path-io generated by st2obs scritpt
